==> dapu-0.0.4-py3-none-any.whl: dapu/agents/agent_drop.py <==
from dapu.agents.agent import AgentGeneric
from dapu.process import logging
from dapu.perks import split_task_id

class Agent(AgentGeneric):
    """
    drop - töötab tulemtabeliga ja teeb Postgre kiiksuga 
    """
        
    def do_action(self) -> bool:
        _, target_schema, target_table = split_task_id(self.task_id)
        sql = self.make_drop_command(self.target_alias, target_schema, target_table, with_cascade=True)
        if sql > '':
            try:
                logging.info(f"DROP current structure (in target base)")
                self.context.target(sql, False)
            except Exception as e1:
                msg = f"Failed DROP command: {sql}"
                self.last_error = msg
                logging.error(msg)
                return False
        
        # tühja SQL-i ei rakenda ja loeme selle õnnestumiseks
        return True


    def make_drop_command(self, target_alias, target_schema: str, target_table: str, with_cascade: bool=False) -> str:
        """
        If object exists in postgre database then return sql command for drop corresponding to object type (table, view, etc)
        Needs database alias
        """
        # Tulembaasis (alati PostrgeSQL) vaja minev tegevus (õiget tüüpi drop käsk) 
        # Postgre metainfo päring, kas objekt on olemas ja mis tüüpi
        
        command = ''  # jääb tühjaks, kui pole vaja droppida
        
        sql = f"""
            SELECT
                CASE 
                    WHEN c.relkind = 'r' THEN 'TABLE' 
                    WHEN c.relkind = 'v' THEN 'VIEW' 
                    WHEN c.relkind = 'm' THEN 'MATERIALIZED VIEW' 
                    ELSE 'ZZ' -- our uncleariness-marker
                END, 
                c.relkind -- for debuging unclear state in far future
            FROM pg_class c 
            JOIN pg_namespace tns ON tns.oid = c.relnamespace 
            WHERE tns.nspname = '{target_schema}' AND c.relname = '{target_table}' 
            UNION SELECT 'XX' -- our non-existence marker
            ORDER BY 1
        """
        result_set = self.context.target(sql)
        
        if result_set:
            unit = (result_set[0][0]).upper()  # unit on "TABLE", "VIEW", "MATERIALIZED VIEW" 
            if unit not in ('XX', 'ZZ'):
                command = f'DROP {unit} IF EXISTS {target_schema}.{target_table}'
                if with_cascade:
                    command = command + ' CASCADE'
            if unit == 'ZZ':
                logging.warning("Unclear tabular type: {result_set[0][1]}")

        return command

==> dapu-0.1.3-py3-none-any.whl: dapu/agents/agent_drop.py <==
from loguru import logger
from dapu.agents.agent import AgentGeneric
from dapu.process import logging
from dapu.perks import split_task_id

class Agent(AgentGeneric):
    """
    drop - töötab tulemtabeliga ja teeb Postgre kiiksuga 
    """
        
    def do_action(self) -> bool:
        _, target_schema, target_table = split_task_id(self.task_id)
        sql = self.make_drop_command(self.target_alias, target_schema, target_table, with_cascade=True)
        if sql > '':
            try:
                logger.info(f"DROP current structure (in target base)")
                self.context.target(sql, False)
            except Exception as e1:
                msg = f"Failed DROP command: {sql}"
                self.last_error = msg
                logger.error(msg)
                return False
        
        # tühja SQL-i ei rakenda ja loeme selle õnnestumiseks
        return True


    def make_drop_command(self, target_alias, target_schema: str, target_table: str, with_cascade: bool=False) -> str:
        """
        If object exists in postgre database then return sql command for drop corresponding to object type (table, view, etc)
        Needs database alias
        """
        # Tulembaasis (alati PostrgeSQL) vaja minev tegevus (õiget tüüpi drop käsk) 
        # Postgre metainfo päring, kas objekt on olemas ja mis tüüpi
        
        command = ''  # jääb tühjaks, kui pole vaja droppida
        
        sql = f"""
            SELECT
                CASE 
                    WHEN c.relkind = 'r' THEN 'TABLE' 
                    WHEN c.relkind = 'v' THEN 'VIEW' 
                    WHEN c.relkind = 'm' THEN 'MATERIALIZED VIEW' 
                    ELSE 'ZZ' -- our uncleariness-marker
                END, 
                c.relkind -- for debuging unclear state in far future
            FROM pg_class c 
            JOIN pg_namespace tns ON tns.oid = c.relnamespace 
            WHERE tns.nspname = '{target_schema}' AND c.relname = '{target_table}' 
            UNION SELECT 'XX' -- our non-existence marker
            ORDER BY 1
        """
        result_set = self.context.target(sql)
        
        if result_set:
            unit = (result_set[0][0]).upper()  # unit on "TABLE", "VIEW", "MATERIALIZED VIEW" 
            if unit not in ('XX', 'ZZ'):
                command = f'DROP {unit} IF EXISTS {target_schema}.{target_table}'
                if with_cascade:
                    command = command + ' CASCADE'
            if unit == 'ZZ':
                logger.warning("Unclear tabular type: {result_set[0][1]}")

        return command
